@@ -1,30 +1,32 @@
+from typing import TYPE_CHECKING, cast
+
 from sqlalchemy.engine import Engine
-from sqlalchemy.ext.asyncio import AsyncEngine, AsyncSession, \
-    create_async_engine
+from sqlalchemy.ext.asyncio import (AsyncEngine, AsyncSession,
+                                    create_async_engine)
 from sqlalchemy.orm import sessionmaker
-from typing import cast, TYPE_CHECKING
 
 from aiohttp_sqlalchemy.constants import DEFAULT_KEY, SA_DEFAULT_KEY
 from aiohttp_sqlalchemy.decorators import sa_decorator
-from aiohttp_sqlalchemy.exceptions import DuplicateAppKeyError, \
-                                          DuplicateRequestKeyError
+from aiohttp_sqlalchemy.exceptions import (DuplicateAppKeyError,
+                                           DuplicateRequestKeyError)
 from aiohttp_sqlalchemy.middlewares import sa_middleware
-from aiohttp_sqlalchemy.utils import init_db, sa_init_db, sa_session
+from aiohttp_sqlalchemy.utils import (init_db, sa_init_db, sa_session,
+                                      sa_session_factory)
 from aiohttp_sqlalchemy.views import SAAbstractView, SABaseView, SAView
 
-
 if TYPE_CHECKING:
     from aiohttp.web import Application
-    from aiohttp_sqlalchemy.typedefs import TBinding, TBindings, TBindTo, \
-        TSessionFactory
+
+    from aiohttp_sqlalchemy.typedefs import (TBinding, TBindings, TBindTo,
+                                             TSessionFactory)
 
 
-__version__ = '0.15.5'
+__version__ = '0.16.0'
 
 __all__ = [
     'bind', 'DuplicateAppKeyError', 'DuplicateRequestKeyError', 'init_db',
     'SAAbstractView', 'SABaseView', 'SA_DEFAULT_KEY', 'sa_decorator',
-    'sa_middleware', 'sa_session', 'SAView', 'setup',
+    'sa_middleware', 'sa_session', 'sa_session_factory', 'SAView', 'setup',
     # synonyms
     'DEFAULT_KEY', 'sa_bind', 'sa_init_db',
 ]
