@@ -1,14 +1,16 @@
 from abc import ABCMeta
+from typing import TYPE_CHECKING
+
 from aiohttp.abc import AbstractView
 from aiohttp.web import View
-from typing import TYPE_CHECKING
 
 from aiohttp_sqlalchemy.constants import SA_DEFAULT_KEY
 
 if TYPE_CHECKING:
-    from sqlalchemy.ext.asyncio import AsyncSession
     from typing import Any, Optional
 
+    from sqlalchemy.ext.asyncio import AsyncSession
+
 
 class SAAbstractView(AbstractView, metaclass=ABCMeta):
     """
@@ -21,7 +23,7 @@ class SAAbstractView(AbstractView, metaclass=ABCMeta):
     sa_session_key: 'str' = SA_DEFAULT_KEY
 
     def sa_session(self, key: 'Optional[str]' = None) -> 'AsyncSession':
-        return self.request[key or self.sa_session_key]
+        return self.request.get(key or self.sa_session_key)
 
 
 class SAOneModelMixin(SAAbstractView, metaclass=ABCMeta):
